// -------------------------------------------------------------------
//
// -------------------------------------------------------------------
// copyright 2000 by voxeo corporation. (see LGPL.txt)
// -------------------------------------------------------------------
//
// v1.0 Coded in Java
// v1.0 Coded by Omi Chandiramani
//
// This application is a very simple "Telephone Simon" that generates
// random sequences of numbers for the caller to input.  Like normal
// simon games, it starts with a one digit sequence, and then increases
// indefinitely until the caller makes a mistake.    
//
// This zip file contains the following files:				 
//     SimonGame.java        <---- This file
//     LGPL.txt              <---- opensource license agreement
//     readme.txt            <---- Useful instructions
//
// Several audio files are associated with this application:
//           Welcome.wav
//           ThankYou.wav
//           OhNo.wav
//           YouAcquired.wav
//           Points.wav
//           TooLong.wav
//
// All audio files are PCM format, 8-bit, mono, unsigned.
//
// This version was tested under JRun 3.0 and Apache 1.3.9.  
//
// Notes for running under JRun:
// -----------------------------
//   From the JRun management console, create a new application
//   under the appropriate server:
//   (JRun default server --> Web applications --> Create an Application).  
//
//   We called it simon, and the code is looking for "simon."  Remember to specify the 
//   application root directory as the same directory in which you installed the code.  
//
//   This will create other subdirectories in the application root directory.
//
//   In the application root directory, copy SimonGame.class to web-inf/classes.
//   Then, in the JMC (JRun management console), click on the "Simon" application
//   you just created, and select "Servlet URL Mappings".
//
//   From here, you can click on edit and map /SimonGame to refer to the
//   SimonGame servlet (this is necessary because within the code itself, 
//   we are looking for "SimonGame").  
//
//   Ultimately, your URL will look something like: 
//     "http://my-url.my-server.com/simon/SimonGame"
//
//   Remember to change the "baseURL" variable in the code before you compile
//   it to reflect this change.
//---------------------------------------------------------------------------

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse; 

import java.io.IOException;
import java.io.PrintWriter;

import java.util.Random;

public class SimonGame extends HttpServlet {

  private PrintWriter out;

  /**
   * Change baseURL to point to your web server!
   */
  private static String baseURL = "http://jrun.voxeo.com:8100/simon";
  private static String servletURL = baseURL + "/SimonGame";
  
  public void doGet (HttpServletRequest request,
                     HttpServletResponse response)
    throws ServletException, IOException
  {

  
    /* set content type */
    response.setContentType("text/html");	
    /* prepare the response output stream for writing  */
    out = response.getWriter();

    /*
     * Initialize the callXML
     */
	
    out.println ("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>");
    out.println ("<callxml>");
	

    /*
     * Figure out which point in the game we are in 
     */

    String mode = getStringParameter (request, "mode");

    if (mode.equals("playing"))
      playing (out, request);
    else if (mode.equals("checking" ))
      checking (out, request);
    else if (mode.equals ("endgame"))
      endGame(out, request);
    else 
      mainMenu (out);

    /*
     * Close the callXML
     */
	
    out.println ("</callxml>");
	
    /* finally close the servlets output stream */
    out.close();
	
  }

  /* 
   * The starting point of the game. 
   * This will play a welcome greeting and 
   * explain the rules.               
   */ 
   
  private void mainMenu(PrintWriter out) {

    out.println ("<block label=\"Main\">");
  
    /*  
     * Here we set three variables.                                 
     * CurrentNumber is the sequence of numbers Simon asks for.     
     * TotalDigits is simply the length of that string of numbers.  
     * Score is basically 50 points times the TotalDigits variable. 
     */  

    out.println ("<assign var=\"currentnumber\" value=\"\"  />");
    out.println ("<assign var=\"totaldigits\"   value=\"0\" />");
    out.println ("<assign var=\"score\"         value=\"0\" />"); 
    
    out.println ("<menu label=\"MainMenu\" " + 
                 "repeat=\"3\" " + 
                 "format=\"audio/wav\" " +
                 "value=\"" + baseURL + "/Welcome.wav\" " +		  
                 "cleardigits=\"TRUE\" " + 
                 "termdigits=\"#\" " + 
                 "maxtime=\"60s\" " +
                 "maxsilence=\"20s\" >");
	       
    /*
     * By hitting the # key, the caller is ready to start. 
     */ 

    out.println ("<ontermdigit value=\"#\">"); 
    out.println ("  <goto value=\"" + servletURL + "?mode=playing\" submit=\"*\" method=\"get\" />"); 
    out.println ("</ontermdigit>");
	  
    /*
     * If the user takes too much time, then 
     * inform them as such and hangup.       
     */

    out.println ("<onmaxtime>");
    out.println ("  <goto value=\"" + baseURL + "/TooLong.wav\" submit=\"*\" method=\"get\" />"); 
    out.println ("</onmaxtime>"); 
	  
    out.println ("<onmaxsilence>");
    out.println ("  <goto value=\"" + baseURL + "/TooLong.wav\" submit=\"*\" method=\"get\" />"); 
    out.println ("</onmaxsilence>");
    out.println ("</menu>");

    out.println ("</block>");


  }

  /* 
   * Figures out the next random number in the
   * sequence and asks the user to punch in the 
   * new number. 
   */
  private void playing(PrintWriter out, HttpServletRequest request) {

    /*
     * Get a random number from 0 - 9
     */
  
    int RandomNumber = Math.abs (new Random().nextInt() % 10);

    /*  												  
     * We simply append a new random digit onto the end	  
     * for each pass through this file.								  
     */ 

    String NewCurrentNumber = getStringParameter(request, "currentnumber") + RandomNumber;
    out.println ("<assign var=\"currentnumber\" value=\"" + NewCurrentNumber + "\" />");    
    
    /*
     * Increase the total number of digits in the sequence 
     */ 

    int NewTotalDigits = getIntParameter (request, "totaldigits") + 1; 
    out.println ("<assign var=\"totaldigits\" value=\"" + NewTotalDigits + "\"/>");

    /*
     * Play the current number sequence for the caller to hear 
     */
	
    out.println ("<playnumber value=\"" + NewCurrentNumber + "\" format=\"digits\" />");
			  
    /*  
     * Get the caller's guess at the digit sequence.  When they 
     * have reached the proper length, go to the "verify" code  
     * to check their answer.  If they take too much time, then 
     * they have forfeited the game.                            
     */  

    out.println ("<block>");
    out.println ("<getdigits var=\"callersguess\" " +
                 "maxdigits=\"" + NewTotalDigits + "\" " +
                 "cleardigits=\"TRUE\" " + 
                 "maxsilence=\"5s\" " +
                 "maxtime=\"30s\"/>");

    out.println ("<onmaxdigits>"); 
    out.println ("  <goto value=\"" + servletURL + "?mode=checking\" submit=\"*\" method=\"get\"/>");
    out.println ("</onmaxdigits>"); 

    out.println ("<onmaxtime>"); 
    out.println ("  <goto value=\"" + servletURL + "?mode=endgame\" submit=\"*\" method=\"get\" />");
    out.println ("</onmaxtime>");
 
    out.println ("<onmaxsilence>");
    out.println ("  <goto value=\"" + servletURL + "?mode=endgame\" submit=\"*\" method=\"get\" />");
    out.println ("</onmaxsilence>"); 
    out.println ("</block>");  


  }

  /*
  * If the caller's guess matches the current sequence  
  * of numbers, then play a little "ding" noise and     
  * increase the length of the sequence.  Otherwise,    
  * the user has lost and we go to our endgame routine. 
  */ 
  
  private void checking (PrintWriter out, HttpServletRequest request) {

    out.println ("<block> ");
  
    if (getStringParameter(request, "currentnumber").equals (getStringParameter(request, "callersguess"))) { 
      out.println ("<playaudio value=\"" + baseURL + "/Ding.wav\" />");
	    
      int NewScore = getIntParameter(request, "score") + 50;
	    
      out.println ("<assign var=\"score\" value=\"" + NewScore + "\" />");
	    
      out.println ("<goto value=\"" + servletURL + "?mode=playing\" method=\"get\" submit=\"*\" />");	  

    } else {
      out.println ("<goto value=\"" + servletURL + "?mode=endgame\" submit=\"*\" method=\"get\" />");
    }  

    out.println ("</block>");

  }

    /*  
     * Since the caller entered an incorrect answer, play 
     * a little "oh no!" sound, then tell them how many   
     * points they scored.                                
     */
	
  private void endGame(PrintWriter out, HttpServletRequest request) { 

    out.println ("<block> ");
	
    out.println ("<playaudio value=\"" + baseURL + "/OhNo.wav\" />");
    out.println ("<playaudio value=\"" + baseURL + "/YouAcquired.wav\" />");  
    out.println ("<playnumber value=\"" + getStringParameter(request, "score") + "\" format=\"number\" />"); 
    out.println ("<playaudio value=\"" + baseURL + "/Points.wav\" />");  
	
    /* 
     * Final menu.  Give them a chance to play 
     * again by pressing the pound key.        
     */ 
	
    out.println ("<menu repeat=\"2\" " +
                 "value=\"" + baseURL + "/ThankYou.wav\" " +
                 "termdigits=\"#\" " + 
                 "cleardigits=\"TRUE\" " +
                 "maxsilence=\"5s\" " +
                 "maxtime=\"30s\">");
	
    out.println ("<ontermdigit value=\"#\">");
    out.println ("  <goto value=\"" + servletURL + "\" method=\"get\" submit=\"*\" />");
    out.println ("</ontermdigit>");
    out.println ("</menu>");
    out.println ("</block>");
	
  }


  /* 
   * Helper function to get integer parameter 
   * values that are passed to the servlet. 
   * Returns 0 if integer parameter wasn't 
   * found
   */
  private int getIntParameter (HttpServletRequest request, String key) { 
    return request.getParameter (key) == null ? 0 : Integer.parseInt(request.getParameter(key)); 
  }
    
  /* 
   * Helper function to get string parameter 
   * values that are passed to the servlet. 
   * Returns "" if integer parameter wasn't 
   * found
   */
  private String getStringParameter (HttpServletRequest request, String key) { 
    return request.getParameter (key) == null ? "" : request.getParameter(key); 
  }
    
}

