<?PHP

// ----------------------------------------------------------------------
// copyright 2000 by voxeo corporation. (see LGPL.txt) 					
// ---------------------------------------------------------------------- 
//																		
// v1.0 Coded in PHP												
// v1.0 Coded by Stephen J. Lewis							
//																		
// This application is a very simple "Telephone Simon" that generates		
// random sequences of numbers for the caller to input.  Like normal		
// simon games, it starts with a one digit sequence, and then increases	
// indefinitely until the caller makes a mistake.    						
//																		
// This zip file contains the following files:				 			
//     Simon.php             <---- This file								
//     LGPL.txt              <---- opensource license agreement			
//     Readme.txt            <---- Introduction to this application					
//																		
// Several audio files are associated with this application:				
//           MainMenu.wav													
//           ThankYou.wav													
//           OhNo.wav															
//           YouAcquired.wav												
//           Points.wav													
//           YouHaveTakenTooLong.wav									    
//                                                                        
// All audio files are PCM format, 8-bit, mono, unsigned.                 
//                                                                        
// ---------------------------------------------------------------------- 

//-----------------------------------------------------------------------------------------

function Initialize() {
  echo "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>";
  echo "<callxml>";
}  // Initialize function

//-----------------------------------------------------------------------------------------

function Closure() {
  echo "</callxml>";
}  // Closure function

//-----------------------------------------------------------------------------------------

function MainMenu() {
  // ---------------------------------------------------------------------- 
  // Welcome to telephone simon.  This is the first file that should be run 
  // This will play a welcome greeting and explain the rules.               
  // ---------------------------------------------------------------------- 

  echo "<block label=\"Main\">";
  
  // ------------------------------------------------------------ 
  // Here we set three variables.                                 
  // CurrentNumber is the sequence of numbers Simon asks for.     
  // TotalDigits is simply the length of that string of numbers.  
  // Score is basically 50 points times the TotalDigits variable. 
  // ------------------------------------------------------------ 

  echo "<assign var=\"currentnumber\" value=\"\"  />";
  echo "<assign var=\"totaldigits\"   value=\"0\" />";
  echo "<assign var=\"score\"         value=\"0\" />"; 

  echo "<block label=\"MainMenu\" " . 
	      "repeat=\"3\" " . 
		  "cleardigits=\"TRUE\">";
		  		  
	  echo "<playaudio format=\"audio/wav\" " .
		              "value=\"MainMenu.wav\" " .		  
	                  "termdigits=\"#\"/>";
					  
	  echo "<wait value=\"3s\" termdigits=\"#\"/>";
		  
	  // --------------------------------------------------- 
	  // By hitting the # key, the caller is ready to start. 
	  // --------------------------------------------------- 

	  echo "<ontermdigit value=\"#\">"; 
	  echo "  <goto value=\"simon.php?menu=playing\" submit=\"*\" method=\"get\" />"; 
	  echo "</ontermdigit>";
	  
	  // -------------------------------------
	  // If the user takes too much time, then 
	  // inform them as such and hangup.       
	  // -------------------------------------

	  echo "<onmaxtime>";
	  echo "  <goto value=\"YouHaveTakenTooLong.wav\" submit=\"*\" method=\"get\" />"; 
	  echo "</onmaxtime>"; 
	  
	  echo "<onmaxsilence>";
	  echo "  <goto value=\"YouHaveTakenTooLong.wav\" submit=\"*\" method=\"get\" />"; 
	  echo "</onmaxsilence>";
    echo "</block>";

  echo "</block>";
}  // MainMenu function

//-----------------------------------------------------------------------------------------

function Checking() {
  global $HTTP_GET_VARS;
  
  echo "<block> ";
  
  // --------------------------------------------------- 
  // If the caller's guess matches the current sequence  
  // of numbers, then play a little "ding" noise and     
  // increase the length of the sequence.  Otherwise,    
  // the user has lost and we go to our endgame routine. 
  // --------------------------------------------------- 
  
  if ($HTTP_GET_VARS["currentnumber"] == $HTTP_GET_VARS["callersguess"]) { 
    echo "<playaudio value=\"Ding.wav\" />";
	
    $NewScore = $HTTP_GET_VARS["score"] + 50;
  
    echo "<assign var=\"score\" value=\"" . $NewScore . "\" />";

    echo "<goto value=\"simon.php?menu=playing\" method=\"get\" submit=\"*\" />";	  
  }  // if statement
  else {
    echo "<goto value=\"simon.php?menu=endgame\" submit=\"*\" method=\"get\" />";
  }  // else statement

  echo "</block> ";
}  // Checking function

//-----------------------------------------------------------------------------------------

function Playing() {
  global $HTTP_GET_VARS;
  
  //---------------------------------
  // Seed the random number generator
  //---------------------------------
  
  srand( ( double ) microtime()*1000000);
  
  // ------------------------------------------------ 												  
  // We simply append a new random digit onto the end	  
  // for each pass through this file.								  
  // ------------------------------------------------

  $NewCurrentNumber = $HTTP_GET_VARS["currentnumber"] . rand(1,9);
  
  echo "<assign var=\"currentnumber\" value=\"" . $NewCurrentNumber . "\" />";    
  
  // --------------------------------------------------- 
  // Increase the total number of digits in the sequence 
  // --------------------------------------------------- 

  $NewTotalDigits = $HTTP_GET_VARS["totaldigits"] + 1;
  
  echo "<assign var=\"totaldigits\" value=\"" . $NewTotalDigits . "\"/>";

  // ------------------------------------------------------- 
  // Play the current number sequence for the caller to hear 
  // ------------------------------------------------------- 
    
  echo "<playnumber value=\"" . $NewCurrentNumber . "\" format=\"digits\" />";
			  
  // -------------------------------------------------------- 
  // Get the caller's guess at the digit sequence.  When they 
  // have reached the proper length, go to the "verify" code  
  // to check their answer.  If they take too much time, then 
  // they have forfeited the game.                            
  // -------------------------------------------------------- 

  echo "<block>";
    echo "<getdigits var=\"callersguess\" " .
			   "maxdigits=\"" . $NewTotalDigits . "\" " .
	  		   "cleardigits=\"TRUE\" " . 
			   "maxsilence=\"5s\" " .
			   "maxtime=\"30s\"/>";

	  echo "<onmaxdigits>"; 
	  echo "  <goto value=\"simon.php?menu=checking\" submit=\"*\" method=\"get\"/>";
	  echo "</onmaxdigits>"; 

	  echo "<onmaxtime>"; 
	  echo "  <goto value=\"simon.php?menu=endgame\" submit=\"*\" method=\"get\" />";
	  echo "</onmaxtime>";
 
	  echo "<onmaxsilence>";
	  echo "  <goto value=\"simon.php?menu=endgame\" submit=\"*\" method=\"get\" />";
	  echo "</onmaxsilence>"; 
  echo "</block>";
}  // Playing function

//-----------------------------------------------------------------------------------------

function EndGameMenu() {
  global $HTTP_GET_VARS;

  echo "<block> ";
  
  // -------------------------------------------------- 
  // Since the caller entered an incorrect answer, play 
  // a little "oh no!" sound, then tell them how many   
  // points they scored.                                
  // -------------------------------------------------- 
  
    echo "<playaudio value=\"OhNo.wav\" />";
    echo "<playaudio value=\"YouAcquired.wav\" />";  
    echo "<playnumber value=\"" . $HTTP_GET_VARS["score"] . "\" format=\"number\" />"; 
    echo "<playaudio value=\"Points.wav\" />";  
  
    // --------------------------------------- 
    // Final menu.  Give them a chance to play 
    // again by pressing the pound key.        
    // --------------------------------------- 
  
    echo "<block repeat=\"2\" " .
		        "cleardigits=\"TRUE\">";
	echo "<playaudio format=\"audio/wav\" " .
	                "value=\"ThankYou.wav\" " .
  	    	        "termdigits=\"#\"/>";
			 
	echo "<wait value=\"3s\" termdigits=\"#\"/>";

	echo "<ontermdigit value=\"#\">";
	echo "  <goto value=\"simon.php\" method=\"get\" submit=\"*\" />";
	echo "</ontermdigit>";
  echo "</block>";
  echo "</block>";
}  // EndGameMenu function

//-----------------------------------------------------------------------------------------

Initialize();

if     ($HTTP_GET_VARS["menu"] == "endgame" ) { EndGameMenu(); }
elseif ($HTTP_GET_VARS["menu"] == "playing" ) { Playing();     }
elseif ($HTTP_GET_VARS["menu"] == "checking") { Checking();    }
else                                          { MainMenu();    }

Closure();

?>