print "Content-type: text/html\n\n";

# ----------------------------------------------------------------------
# copyright 2000 by voxeo corporation. (see LGPL.txt) 					
# ---------------------------------------------------------------------- 
#																		
# v1.0 Coded in Perl												
# v1.0 Coded by Stephen J. Lewis							
#																		
# This application is a very simple "Telephone Simon" that generates		
# random sequences of numbers for the caller to input.  Like normal		
# simon games, it starts with a one digit sequence, and then increases	
# indefinitely until the caller makes a mistake.    	
#
# Requires:
#     CGI.pm					
#																		
# This zip file contains the following files:				 			
#     Simon.pl              <---- This file								
#     LGPL.txt              <---- opensource license agreement			
#     Readme.txt            <---- Introduction to this application					
#																		
# Several audio files are associated with this application:				
#           MainMenu.wav													
#           ThankYou.wav													
#           OhNo.wav															
#           YouAcquired.wav												
#           Points.wav													
#           YouHaveTakenTooLong.wav									    
#                                                                        
# All audio files are PCM format, 8-bit, mono, unsigned.                 
#                                                                        
# ---------------------------------------------------------------------- 

#-----------------------------------------------------------------------------------------

sub Initialize() {
  print "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>";
  print "<callxml>";
  
  #------------------------------
  # Create a new cgi query module
  #------------------------------
  
  $query = new CGI;  
  
  $TotalDigits   = $query->param('totaldigits');
  $CurrentNumber = $query->param('currentnumber');   
  $Menu          = $query->param('menu');
  $CallersGuess  = $query->param('callersguess'); 
  $Score         = $query->param('score');  
}  # Initialize sub

#-----------------------------------------------------------------------------------------

sub Closure() {
  print "</callxml>";
}  # Closure sub

#-----------------------------------------------------------------------------------------

sub MainMenu() {
  # ---------------------------------------------------------------------- 
  # Welcome to telephone simon.  This is the first file that should be run 
  # This will play a welcome greeting and explain the rules.               
  # ---------------------------------------------------------------------- 

  print "<block label=\"Main\">";
  
  # ------------------------------------------------------------ 
  # Here we set three variables.                                 
  # CurrentNumber is the sequence of numbers Simon asks for.     
  # TotalDigits is simply the length of that string of numbers.  
  # Score is basically 50 points times the TotalDigits variable. 
  # ------------------------------------------------------------ 

  print "<assign var=\"currentnumber\" value=\"\"  />";
  print "<assign var=\"totaldigits\"   value=\"0\" />";
  print "<assign var=\"score\"         value=\"0\" />"; 

  print "<block label=\"MainMenu\" " . 
	      "repeat=\"3\" " . 
		  "cleardigits=\"TRUE\">";
		  		  
	  print "<playaudio format=\"audio/wav\" " .
		              "value=\"MainMenu.wav\" " .		  
	                  "termdigits=\"#\"/>";
					  
	  print "<wait value=\"3s\" termdigits=\"#\"/>";
		  
	  # --------------------------------------------------- 
	  # By hitting the # key, the caller is ready to start. 
	  # --------------------------------------------------- 

	  print "<ontermdigit value=\"#\">"; 
	  print "  <goto value=\"simon.pl?menu=playing\" submit=\"*\" method=\"get\" />"; 
	  print "</ontermdigit>";
	  
	  # -------------------------------------
	  # If the user takes too much time, then 
	  # inform them as such and hangup.       
	  # -------------------------------------

	  print "<onmaxtime>";
	  print "  <goto value=\"YouHaveTakenTooLong.wav\" submit=\"*\" method=\"get\" />"; 
	  print "</onmaxtime>"; 
	  
	  print "<onmaxsilence>";
	  print "  <goto value=\"YouHaveTakenTooLong.wav\" submit=\"*\" method=\"get\" />"; 
	  print "</onmaxsilence>";
    print "</block>";

  print "</block>";
}  # MainMenu sub

#-----------------------------------------------------------------------------------------

sub Checking() {
  print "<block> ";
  
  # --------------------------------------------------- 
  # If the caller's guess matches the current sequence  
  # of numbers, then play a little "ding" noise and     
  # increase the length of the sequence.  Otherwise,    
  # the user has lost and we go to our endgame routine. 
  # --------------------------------------------------- 
  
  if ($CurrentNumber eq $CallersGuess) { 
    print "<playaudio value=\"Ding.wav\" />";
	
    $NewScore = $Score + 50;
  
    print "<assign var=\"score\" value=\"" . $NewScore . "\" />";

    print "<goto value=\"simon.pl?menu=playing\" method=\"get\" submit=\"*\" />";	  
  }  # if statement
  else {
    print "<goto value=\"simon.pl?menu=endgame\" submit=\"*\" method=\"get\" />";
  }  # else statement

  print "</block> ";
}  # Checking sub

#-----------------------------------------------------------------------------------------

sub Playing() {
  #---------------------------------
  # Seed the random number generator
  #---------------------------------
  
  srand;
  
  # ------------------------------------------------ 												  
  # We simply append a new random digit onto the end	  
  # for each pass through this file.								  
  # ------------------------------------------------
  
  $RandomNumber = rand(10);
  $RandomNumber = substr($RandomNumber,0,1); 
  $NewCurrentNumber = $CurrentNumber . $RandomNumber;
  
  print "<assign var=\"currentnumber\" value=\"" . $NewCurrentNumber . "\" />";    
  
  # --------------------------------------------------- 
  # Increase the total number of digits in the sequence 
  # --------------------------------------------------- 

  $NewTotalDigits = $TotalDigits + 1;
  
  print "<assign var=\"totaldigits\" value=\"" . $NewTotalDigits . "\"/>";

  # ------------------------------------------------------- 
  # Play the current number sequence for the caller to hear 
  # ------------------------------------------------------- 
    
  print "<playnumber value=\"" . $NewCurrentNumber . "\" format=\"digits\" />";
			  
  # -------------------------------------------------------- 
  # Get the caller's guess at the digit sequence.  When they 
  # have reached the proper length, go to the "verify" code  
  # to check their answer.  If they take too much time, then 
  # they have forfeited the game.                            
  # -------------------------------------------------------- 

  print "<block>";
    print "<getdigits var=\"callersguess\" " .
			   "maxdigits=\"" . $NewTotalDigits . "\" " .
	  		   "cleardigits=\"TRUE\" " . 
			   "maxsilence=\"5s\" " .
			   "maxtime=\"30s\"/>";

	  print "<onmaxdigits>"; 
	  print "  <goto value=\"simon.pl?menu=checking\" submit=\"*\" method=\"get\"/>";
	  print "</onmaxdigits>"; 

	  print "<onmaxtime>"; 
	  print "  <goto value=\"simon.pl?menu=endgame\" submit=\"*\" method=\"get\" />";
	  print "</onmaxtime>";
 
	  print "<onmaxsilence>";
	  print "  <goto value=\"simon.pl?menu=endgame\" submit=\"*\" method=\"get\" />";
	  print "</onmaxsilence>"; 
  print "</block>";
}  # Playing sub

#-----------------------------------------------------------------------------------------

sub EndGameMenu() {
  print "<block> ";
  
  # -------------------------------------------------- 
  # Since the caller entered an incorrect answer, play 
  # a little "oh no!" sound, then tell them how many   
  # points they scored.                                
  # --------------------------------------------------
  
  if ($Score eq "") { $Score = "0"; }
  
  print "<playaudio value=\"OhNo.wav\" />";
  print "<playaudio value=\"YouAcquired.wav\" />";  
  print "<playnumber value=\"" . $Score . "\" format=\"number\" />"; 
  print "<playaudio value=\"Points.wav\" />";  
  
  # --------------------------------------- 
  # Final menu.  Give them a chance to play 
  # again by pressing the pound key.        
  # --------------------------------------- 
  
  print "<block repeat=\"2\" " .
		        "cleardigits=\"TRUE\">";
  print "<playaudio format=\"audio/wav\" " .
	                "value=\"ThankYou.wav\" " .
  	    	        "termdigits=\"#\"/>";
			 
  print "<wait value=\"3s\" termdigits=\"#\"/>";

  print "<ontermdigit value=\"#\">";
  print "  <goto value=\"simon.pl\" method=\"get\" submit=\"*\" />";
  print "</ontermdigit>";
  print "</block>";
  print "</block>";
}  # EndGameMenu sub

#-----------------------------------------------------------------------------------------

# ------------------------
# Initialize the perl libs
# ------------------------
  
use CGI;

&Initialize();

if    ($Menu eq "endgame" ) { &EndGameMenu(); }
elsif ($Menu eq "playing" ) { &Playing();     }
elsif ($Menu eq "checking") { &Checking();    }
else                        { &MainMenu();    }

&Closure();